@@ -28,7 +28,7 @@ This is based on the context menu code available here:
 /** @ngInject */
 export function contextMenuAsDirective() {
   'use strict';
-  return ["$parse", "$q", "$sce", function ($parse, $q, $sce) {
+  return ["$parse", "$q", function ($parse, $q) {
 
     var _contextMenus = [];
     // Contains the element that was clicked to show the context menu
@@ -113,7 +113,7 @@ export function contextMenuAsDirective() {
       }
 
       $li.append(optionText);
-    };
+    }
 
     /**
      * Process each individual item
@@ -135,7 +135,6 @@ export function contextMenuAsDirective() {
       // if first item in the item array is a function then invoke .call()
       // if first item is a string, then text should be the string.
 
-      var text = DEFAULT_ITEM_TEXT;
       var currItemParam = angular.extend({}, params);
       currItemParam.nestedMenu = nestedMenu;
       currItemParam.enabled = isOptionEnabled(currItemParam);
@@ -143,7 +142,7 @@ export function contextMenuAsDirective() {
 
       registerCurrentItemEvents(currItemParam);
 
-    };
+    }
 
     /*
      * Registers the appropriate mouse events for options if the item is enabled.
@@ -232,7 +231,7 @@ export function contextMenuAsDirective() {
         });
         $li.addClass('disabled');
       }
-    };
+    }
 
     /**
      * @param params - an object containing the `item` parameter
@@ -282,12 +281,14 @@ export function contextMenuAsDirective() {
       /// <summary>Render context menu recursively.</summary>
 
       // Destructuring:
+      var options = params.options;
+      /*
       var $scope = params.$scope;
       var event = params.event;
-      var options = params.options;
       var modelValue = params.modelValue;
       var level = params.level;
       var customClass = params.customClass;
+      */
 
       // Initialize the container. This will be passed around
       var $ul = initContextMenuContainer(params);
@@ -321,7 +322,7 @@ export function contextMenuAsDirective() {
       $(document).find('body').append($ul);
 
       doAfterAllPromises(params);
-    };
+    }
 
     /**
      * calculate if drop down menu would go out of screen at left or bottom
@@ -370,7 +371,7 @@ export function contextMenuAsDirective() {
           if (winWidth - leftCoordinate > menuWidth && leftCoordinate < menuWidth + padding) {
             leftCoordinate = padding;
           } else if (leftCoordinate < menuWidth) {
-            var reduceThresholdX = 5;
+            let reduceThresholdX = 5;
             if (winWidth - leftCoordinate < reduceThresholdX + padding) {
               reduceThresholdX = winWidth - leftCoordinate + padding;
             }
@@ -382,7 +383,7 @@ export function contextMenuAsDirective() {
           if (leftCoordinate > menuWidth && winWidth - leftCoordinate - padding < menuWidth) {
             leftCoordinate = winWidth - menuWidth - padding;
           } else if(winWidth - leftCoordinate < menuWidth) {
-            var reduceThresholdX = 5;
+            let reduceThresholdX = 5;
             if(leftCoordinate < reduceThresholdX + padding) {
               reduceThresholdX = leftCoordinate + padding;
             }
@@ -398,7 +399,7 @@ export function contextMenuAsDirective() {
         });
       });
 
-    };
+    }
 
     /**
      * Creates the container of the context menu (a <ul> element),
@@ -442,7 +443,7 @@ export function contextMenuAsDirective() {
       } else {
         return true;
       }
-    };
+    }
 
     function isTouchDevice() {
       return 'ontouchstart' in window  || navigator.maxTouchPoints; // works on most browsers | works on IE10/11 and Surface
@@ -481,7 +482,7 @@ export function contextMenuAsDirective() {
       }
     }
 
-    function removeAllContextMenus(e) {
+    function removeAllContextMenus() {
       $(document.body).off('mousedown', removeOnOutsideClickEvent);
       $(document).off('scroll', removeOnScrollEvent);
       $(_clickedElement).removeClass('context');
