@@ -5,9 +5,11 @@ import {UI} from '../datasources/fault-ds/UI';
 import {API} from '../opennms';
 import {Mapping} from '../datasources/fault-ds/Mapping';
 import {FilterCloner} from '../datasources/fault-ds/FilterCloner';
-import {OpenNMSFMDatasource as Datasource} from '../datasources/fault-ds/datasource'
+import {OpenNMSFMDatasource as Datasource} from '../datasources/fault-ds/datasource';
 import {ClientDelegate} from '../lib/client_delegate';
 
+import {TemplateSrv} from './template_srv';
+
 describe("OpenNMS_FaultManagement_Datasource", function() {
     let uiSegmentSrv = {
         newSegment: function (value, type) {
@@ -19,7 +21,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
         newOperator: function (operator) {
             return this.newSegment(operator, 'operator');
         },
-        newFake: function (text, type, cssClass) {
+        newFake: function (text, type /*, cssClass */) {
             let segment = this.newSegment(text, type);
             segment.fake = true;
             return segment;
@@ -86,7 +88,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                 expect(mapping.getApiOperator(UI.Operators.OR)).to.eql(API.Operators.OR);
 
                 done();
-            })
+            });
         });
 
         describe('RestrictionMapping', function () {
@@ -240,7 +242,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
             restriction.setComparator("=");
             restriction.setValue("my value");
             expect(restriction.asRestrictionDTO()).not.to.eql(null);
-            expect(restriction.asRestrictionDTO()).to.eql(new UI.RestrictionDTO("my attribute", "=", "my value"))
+            expect(restriction.asRestrictionDTO()).to.eql(new UI.RestrictionDTO("my attribute", "=", "my value"));
         });
     });
 
@@ -289,7 +291,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                     expect(control.filter(uiFilter.query, new UI.Clause(uiSegmentSrv, UI.Operators.AND, new UI.Query(uiSegmentSrv)))).to.eql(false);
 
                     done();
-                })
+                });
             });
 
             describe("action", function() {
@@ -422,7 +424,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
 
 
                     done();
-                })
+                });
             });
         });
     });
@@ -452,7 +454,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                 expect(() => uiFilter.addClause("string")).to.throw("Clause type is not supported");
 
                 done();
-            })
+            });
         });
 
         describe('removeClause', function() {
@@ -625,7 +627,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                 expect(clause.controls.length).to.eql(controls.length); // add, add nested and remove
                 if (controls.length > 0) {
                     _.each(controls, (control, index) => {
-                       expect(clause.controls[index]).to.be.an.instanceof(control)
+                       expect(clause.controls[index]).to.be.an.instanceof(control);
                     });
                 }
             };
@@ -676,7 +678,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
 
                 done();
             });
-        })
+        });
     });
 
     describe('ClientDelegate', () => {
@@ -689,7 +691,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                 type: "opennms-fm",
                 name: "dummy-name",
                 url: "http://localhost:8980/opennms"
-            }
+            };
        });
 
        it('should not throw an exception when supported version is used', (done) => {
@@ -707,7 +709,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
 
            // Instantiate and try to do any operation on the delegate
            const delegate = new ClientDelegate(ctx.settings, ctx.backendSrv, ctx.$q);
-           delegate.getClientWithMetadata().then((metadata) => {
+           delegate.getClientWithMetadata().then(() => {
                done();
            });
        });
@@ -752,7 +754,7 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
             // Context initialization
             ctx.$q = Q;
             ctx.backendSrv = {};
-            ctx.templateSrv = {replace: (value, scopedVars) => value};
+            ctx.templateSrv = new TemplateSrv();
             ctx.uiSegmentSrv = uiSegmentSrv;
             ctx.contextSrv = {user: {login: "admin", email: "admin@opennms.org", name:"The Administrator"}};
             ctx.range_from = moment();
@@ -822,12 +824,6 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
 
         describe('buildQuery', () => {
             it('should substitute scoped variables', () => {
-                // Mock the replace function
-                ctx.templateSrv.replace = (value, scopedVars) => {
-                    return value.replace(/\$variable1/g, scopedVars['variable1'].value)
-                        .replace(/\[\[variable1\]\]/g, scopedVars['variable1'].value);
-                };
-
                 // The filter with variables
                 const filter = new API.Filter()
                     .withClause(new API.Clause(new API.Restriction("key", API.Comparators.EQ, "$variable1"), API.Operators.AND))
@@ -841,15 +837,22 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                     }
                 };
 
-                const substituedFilter = ctx.datasource.buildQuery(filter, options);
+                const substitutedFilter = ctx.datasource.buildQuery(filter, options);
 
                 // Verify
-                expect(substituedFilter.clauses[0].restriction.value).to.equal("dummy-value");
-                expect(substituedFilter.clauses[1].restriction.value).to.equal("Hello this is my dummy-value");
-                expect(substituedFilter.clauses[2].restriction.value).to.equal("value3");
+                expect(substitutedFilter.clauses[0].restriction.value).to.equal("dummy-value");
+                expect(substitutedFilter.clauses[1].restriction.value).to.equal("Hello this is my dummy-value");
+                expect(substitutedFilter.clauses[2].restriction.value).to.equal("value3");
             });
 
             it('should substitude $range_from and $range_to accordingly', () => {
+                // The input filter
+                const filter = new API.Filter()
+                    .withClause(new API.Clause(new API.Restriction("key", API.Comparators.EQ, "$range_from"), API.Operators.AND))
+                    .withClause(new API.Clause(new API.Restriction("key2", API.Comparators.EQ, "$range_to"), API.Operators.AND))
+                    .withClause(new API.Clause(new API.Restriction("key3", API.Comparators.EQ, "[[range_from]]"), API.Operators.AND))
+                    .withClause(new API.Clause(new API.Restriction("key4", API.Comparators.EQ, "[[range_to]]"), API.Operators.AND));
+
                 // Options
                 const options = {
                     targets: [filter],
@@ -860,19 +863,12 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                     scopedVars: {}
                 };
 
-                // The input filter
-                const filter = new API.Filter()
-                    .withClause(new API.Clause(new API.Restriction("key", API.Comparators.EQ, "$range_from"), API.Operators.AND))
-                    .withClause(new API.Clause(new API.Restriction("key2", API.Comparators.EQ, "$range_to"), API.Operators.AND))
-                    .withClause(new API.Clause(new API.Restriction("key3", API.Comparators.EQ, "[[range_from]]"), API.Operators.AND))
-                    .withClause(new API.Clause(new API.Restriction("key4", API.Comparators.EQ, "[[range_to]]"), API.Operators.AND));
-
                 // Build query and verify
-                const substituedFilter = ctx.datasource.buildQuery(filter, options);
-                expect(substituedFilter.clauses[0].restriction.value).to.equal(ctx.range_from);
-                expect(substituedFilter.clauses[1].restriction.value).to.equal(ctx.range_to);
-                expect(substituedFilter.clauses[2].restriction.value).to.equal(ctx.range_from);
-                expect(substituedFilter.clauses[3].restriction.value).to.equal(ctx.range_to);
+                const substitutedFilter = ctx.datasource.buildQuery(filter, options);
+                expect(substitutedFilter.clauses[0].restriction.value).to.equal(ctx.range_from);
+                expect(substitutedFilter.clauses[1].restriction.value).to.equal(ctx.range_to);
+                expect(substitutedFilter.clauses[2].restriction.value).to.equal(ctx.range_from);
+                expect(substitutedFilter.clauses[3].restriction.value).to.equal(ctx.range_to);
             });
 
             it ('should include $range_from and $range_to when building the query', () => {
@@ -894,6 +890,87 @@ describe("OpenNMS_FaultManagement_Datasource", function() {
                expect(actualFilter.clauses[0].restriction.clauses[1].restriction.value).to.equal(ctx.range_to);
 
             });
+
+            it ('should turn a node criteria fs:fid restriction into 2 separate clauses', () => {
+                const filter = new API.Filter()
+                    .withClause(new API.Clause(new API.Restriction('node', API.Comparators.EQ, 'FS:FID'), API.Operators.AND));
+
+                const actualFilter = ctx.datasource.buildQuery(filter, {});
+                expect(filter).not.to.equal(actualFilter);
+                expect(actualFilter.clauses.length).to.equal(1);
+                expect(actualFilter.clauses[0].restriction.clauses[0].restriction.value).to.equal('FS');
+                expect(actualFilter.clauses[0].restriction.clauses[1].restriction.value).to.equal('FID');
+            });
+
+            it ('should turn a node criteria ID restriction into a node.id clause', () => {
+                const filter = new API.Filter()
+                    .withClause(new API.Clause(new API.Restriction('node', API.Comparators.EQ, '1'), API.Operators.AND));
+
+                const actualFilter = ctx.datasource.buildQuery(filter, {});
+                expect(filter).not.to.equal(actualFilter);
+                expect(actualFilter.clauses.length).to.equal(1);
+                expect(actualFilter.clauses[0].restriction.attribute).to.equal('node.id');
+                expect(actualFilter.clauses[0].restriction.value).to.equal('1');
+            });
+
+            it ('should handle multi-select with 0 values selected', () => {
+                const filter = new API.Filter()
+                    .withClause(new API.Clause(new API.Restriction('severity', API.Comparators.EQ, '$severity'), API.Operators.AND));
+
+                ctx.templateSrv.init([{
+                    name: 'severity',
+                    multi: true,
+                    current: {
+                        value: []
+                    }
+                }]);
+
+                const actualFilter = ctx.datasource.buildQuery(filter, {});
+                expect(filter).not.to.equal(actualFilter);
+                expect(actualFilter.clauses.length).to.equal(1);
+                expect(actualFilter.clauses[0].restriction.clauses).not.to.equal(null);
+                expect(actualFilter.clauses[0].restriction.clauses.length).to.equal(0);
+            });
+
+            it ('should handle multi-select with 1 value selected', () => {
+                const filter = new API.Filter()
+                    .withClause(new API.Clause(new API.Restriction('severity', API.Comparators.EQ, '$severity'), API.Operators.AND));
+
+                ctx.templateSrv.init([{
+                    name: 'severity',
+                    multi: true,
+                    current: {
+                        value: ['NORMAL']
+                    }
+                }]);
+
+                const actualFilter = ctx.datasource.buildQuery(filter, {});
+                expect(filter).not.to.equal(actualFilter);
+                expect(actualFilter.clauses.length).to.equal(1);
+                expect(actualFilter.clauses[0].restriction.attribute).to.equal('severity');
+                expect(actualFilter.clauses[0].restriction.value).to.equal('NORMAL');
+            });
+
+            it ('should handle multi-select with 2 values selected', () => {
+                const filter = new API.Filter()
+                    .withClause(new API.Clause(new API.Restriction('severity', API.Comparators.EQ, '$severity'), API.Operators.AND));
+
+                ctx.templateSrv.init([{
+                    name: 'severity',
+                    multi: true,
+                    current: {
+                        value: ['NORMAL', 'WARNING']
+                    }
+                }]);
+
+                const actualFilter = ctx.datasource.buildQuery(filter, {});
+                expect(filter).not.to.equal(actualFilter);
+                expect(actualFilter.clauses.length).to.equal(1);
+                expect(actualFilter.clauses[0].restriction.clauses).not.to.equal(null);
+                expect(actualFilter.clauses[0].restriction.clauses.length).to.equal(2);
+                expect(actualFilter.clauses[0].restriction.clauses[0].restriction.value).to.equal('NORMAL');
+                expect(actualFilter.clauses[0].restriction.clauses[1].restriction.value).to.equal('WARNING');
+            });
         });
     });
 
